import * as tslib_1 from "tslib";
import { getCurrentHub } from '@sentry/core';
import { Severity } from '@sentry/types';
import { fill } from '@sentry/utils';
import * as util from 'util';
/** Console module integration */
var Console = /** @class */ (function () {
    function Console() {
        /**
         * @inheritDoc
         */
        this.name = Console.id;
    }
    /**
     * @inheritDoc
     */
    Console.prototype.setupOnce = function () {
        var nativeModule = require('module');
        fill(nativeModule, '_load', loadWrapper(nativeModule));
        // special case: since console is built-in and app-level code won't require() it, do that here
        require('console');
    };
    /**
     * @inheritDoc
     */
    Console.id = 'Console';
    return Console;
}());
export { Console };
/**
 * Wrapper function for internal _load calls within `require`
 */
function loadWrapper(nativeModule) {
    // We need to use some functional-style currying to pass values around
    // as we cannot rely on `bind`, because this has to preserve correct
    // context for native calls
    return function (originalLoad) {
        return function (moduleId) {
            var originalModule = originalLoad.apply(nativeModule, arguments);
            if (moduleId !== 'console' || originalModule.__sentry__) {
                return originalModule;
            }
            ['debug', 'info', 'warn', 'error', 'log'].forEach(consoleWrapper(originalModule));
            originalModule.__sentry__ = true;
            return originalModule;
        };
    };
}
/**
 * Wrapper function that'll be used for every console level
 */
function consoleWrapper(originalModule) {
    return function (level) {
        if (!(level in originalModule)) {
            return;
        }
        fill(originalModule, level, function (originalConsoleLevel) {
            var sentryLevel;
            switch (level) {
                case 'debug':
                    sentryLevel = Severity.Debug;
                    break;
                case 'error':
                    sentryLevel = Severity.Error;
                    break;
                case 'info':
                    sentryLevel = Severity.Info;
                    break;
                case 'warn':
                    sentryLevel = Severity.Warning;
                    break;
                default:
                    sentryLevel = Severity.Log;
            }
            return function () {
                if (getCurrentHub().getIntegration(Console)) {
                    getCurrentHub().addBreadcrumb({
                        category: 'console',
                        level: sentryLevel,
                        message: util.format.apply(undefined, arguments),
                    }, {
                        input: tslib_1.__spread(arguments),
                        level: level,
                    });
                }
                originalConsoleLevel.apply(originalModule, arguments);
            };
        });
    };
}
//# sourceMappingURL=console.js.map